package RevisionRemover::CMS;

use strict;

sub remove_revision {
    my $app = shift;
    my @ids = $app->param('id');
    my $blog_id = $app->param('blog_id');

    my $plugin = MT->component("RevisionRemover");
    my $rest_revision = $plugin->get_config_value('rest_revision', 'blog:'.$blog_id);
    for my $id (@ids) {
        my $entry = MT::Entry->load($id);
        my $datasource = $entry->datasource;
        my $rev_class  = MT->model( $datasource . ':revision' );
        my $terms = { $datasource . '_id' => $id };
        my $count = $rev_class->count($terms);
        if ( $rest_revision < $count ) {
            my $rev_iter = $rev_class->load_iter(
                $terms,
                {   sort      => 'created_on',
                    direction => 'ascend',
                    limit     => $count - $rest_revision
                }
            );
            while ( my $rev = $rev_iter->() ) {
                $rev->remove;
            }
        }
        $entry->current_revision($rest_revision);
        $entry->save;
    }
    $app->call_return;
}
sub html {
    my ( $prop, $obj, $app ) = @_;
    my $rev = $obj->current_revision;

    my $datasource = $obj->datasource;
    my $rev_class  = MT->model( $datasource . ':revision' );
    my $terms = { $datasource . '_id' => $obj->id };
    my $count = $rev_class->count($terms);

    return $count;

}
sub bulk_sort {
    my $prop = shift;
    my ($objs) = @_;
    my %entry_id = map { $_->id => 1 } @$objs;
    my @entries = MT->model('entry')->load( { id => [ keys %entry_id ] } );
    my %revision = map { $_->id => $_->current_revision } @entries;
    return sort {
        $revision{ $a->id } <=> $revision{ $b->id }
    } @$objs;
}

1;
